@@ -1,6 +1,8 @@
 package Cassandra::Client::Policy::Throttle::Adaptive;
+our $AUTHORITY = 'cpan:TVDW';
+$Cassandra::Client::Policy::Throttle::Adaptive::VERSION = '0.11_003'; # TRIAL
 
-use 5.010;
+$Cassandra::Client::Policy::Throttle::Adaptive::VERSION = '0.11003';use 5.010;
 use strict;
 use warnings;
 use Time::HiRes qw/CLOCK_MONOTONIC/;
@@ -50,3 +52,28 @@ sub count {
 }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Cassandra::Client::Policy::Throttle::Adaptive
+
+=head1 VERSION
+
+version 0.11_003
+
+=head1 AUTHOR
+
+Tom van der Woerdt <tvdw@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Tom van der Woerdt.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
