@@ -1,19 +1,11 @@
 package Cassandra::Client::ResultSet;
-use 5.010;
+our $AUTHORITY = 'cpan:TVDW';
+$Cassandra::Client::ResultSet::VERSION = '0.11_003'; # TRIAL
+
+$Cassandra::Client::ResultSet::VERSION = '0.11003';use 5.010;
 use strict;
 use warnings;
 
-=pod
-
-=head1 NAME
-
-Cassandra::Client::ResultSet - container for rows returned from a query
-
-=head1 METHODS
-
-=over
-
-=cut
 
 sub new {
     my ($class, $rows, $headers, $next_page)= @_;
@@ -25,21 +17,11 @@ sub new {
     }, $class;
 }
 
-=item $result->rows()
-
-Returns an arrayref of all rows in the ResultSet. Each row will be represented as an arrayref with cells. To find column names, see C<column_names>.
-
-=cut
 
 sub rows {
     $_[0]{rows}
 }
 
-=item $result->row_hashes()
-
-Returns an arrayref of all rows in the ResultSet. Each row will be represented as a hashref with cells.
-
-=cut
 
 sub row_hashes {
     my $self= shift;
@@ -57,28 +39,62 @@ sub row_hashes {
     return \@result;
 }
 
-=item $result->column_names()
-
-Returns an arrayref with the names of the columns in the result set, to be used with rows returned from C<rows()>.
-
-=cut
 
 sub column_names {
     $_[0]{headers}
 }
 
-=item $result->next_page()
-
-Returns a string pointing to the next Cassandra result page, if any. Used internally by C<< $client->each_page() >>, but can be used to implement custom pagination logic.
-
-=cut
 
 sub next_page {
     $_[0]{next_page}
 }
 
-=back
-
-=cut
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Cassandra::Client::ResultSet
+
+=head1 VERSION
+
+version 0.11_003
+
+=head1 METHODS
+
+=over
+
+=item $result->rows()
+
+Returns an arrayref of all rows in the ResultSet. Each row will be represented as an arrayref with cells. To find column names, see C<column_names>.
+
+=item $result->row_hashes()
+
+Returns an arrayref of all rows in the ResultSet. Each row will be represented as a hashref with cells.
+
+=item $result->column_names()
+
+Returns an arrayref with the names of the columns in the result set, to be used with rows returned from C<rows()>.
+
+=item $result->next_page()
+
+Returns a string pointing to the next Cassandra result page, if any. Used internally by C<< $client->each_page() >>, but can be used to implement custom pagination logic.
+
+=back
+
+=head1 AUTHOR
+
+Tom van der Woerdt <tvdw@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Tom van der Woerdt.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
