@@ -1,10 +1,13 @@
 package Cassandra::Client::TLSHandling;
-use 5.010;
+our $AUTHORITY = 'cpan:TVDW';
+$Cassandra::Client::TLSHandling::VERSION = '0.11_003'; # TRIAL
+
+$Cassandra::Client::TLSHandling::VERSION = '0.11003';use 5.010;
 use strict;
 use warnings;
 
 # SSLeay needs initialization
-use Net::SSLeay qw/die_now MODE_ENABLE_PARTIAL_WRITE MODE_ACCEPT_MOVING_WRITE_BUFFER/;
+use Net::SSLeay 1.63 qw/die_now MODE_ENABLE_PARTIAL_WRITE MODE_ACCEPT_MOVING_WRITE_BUFFER/;
 BEGIN {
     Net::SSLeay::load_error_strings();
     Net::SSLeay::SSLeay_add_ssl_algorithms();
@@ -42,7 +45,10 @@ sub DESTROY {
 1;
 
 package Cassandra::Client::TLSHandling::conn;
-use 5.010;
+our $AUTHORITY = 'cpan:TVDW';
+$Cassandra::Client::TLSHandling::conn::VERSION = '0.11_003'; # TRIAL
+
+$Cassandra::Client::TLSHandling::conn::VERSION = '0.11003';use 5.010;
 use strict;
 use warnings;
 
@@ -57,3 +63,28 @@ sub DESTROY {
 }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Cassandra::Client::TLSHandling
+
+=head1 VERSION
+
+version 0.11_003
+
+=head1 AUTHOR
+
+Tom van der Woerdt <tvdw@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Tom van der Woerdt.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
